toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'CardInfo{cardType: $cardType, cardStatus: $cardStatus, cardNo: $cardNo, cardValidThru: $cardValidThru, cardHolderName: $cardHolderName, encTrack1: $encTrack1, encTrack2: $encTrack2, encTrack3: $encTrack3, icData55: $icData55, cardSequence: $cardSequence, responseCode: $responseCode, comments: $comments, serviceCode: $serviceCode, responseStatus: $responseStatus}';
}